@@ -16,7 +16,10 @@ $kronolith_configured = (@is_readable(KRONOLITH_BASE . '/config/conf.php') &&
 if ($kronolith_configured) {
     include_once KRONOLITH_BASE . '/lib/base.php';
     
-    $uri = 'month.php';
+    $uri = $prefs->getValue('defaultview') . '.php';
+    if ($uri == '.php') {
+        $uri = 'month.php';
+    }
     if (!empty($HTTP_SERVER_VARS['QUERY_STRING'])) {
         $uri .= '?' . $HTTP_SERVER_VARS['QUERY_STRING'];
     }
@@ -26,15 +29,7 @@ if ($kronolith_configured) {
     
 /* Kronolith isn't configured */
 } else {
-    // We have to guess where Horde is.
-    define('HORDE_BASE', dirname(__FILE__) . '/..');
-    include HORDE_BASE . '/config/horde.php';
-    include_once KRONOLITH_BASE . '/lib/Kronolith.php';
-    
-    $title = _("Kronolith is not fully configured.");
-    include KRONOLITH_BASE . '/templates/common-header.inc';
     include KRONOLITH_BASE . '/templates/index/notconfigured.inc';
-    include KRONOLITH_BASE . '/templates/common-footer.inc';
 }
 
 ?>
