@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: kronolith/mini_month.php,v 1.7 2001/03/18 18:26:43 chuck Exp $
+ * $Horde: kronolith/mini_month.php,v 1.8 2001/07/17 10:12:25 avsm Exp $
  *
  * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
  *
@@ -16,6 +16,6 @@ $month = Horde::getFormData('month', '');
 $day = Horde::getFormData('day', '');
 $year = Horde::getFormData('year', '');
 $month = new Kronolith_MonthView($month, $day, $year);
-echo $month->html($conf['paths']['templates']);
+echo $month->html($registry->getTemplatePath());
 
 ?>
